==> aria2_0.9.0.orig.tar.gz: aria2-0.9.0/src/HttpDownloadCommand.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef _D_HTTP_DOWNLOAD_COMMAND_H_
#define _D_HTTP_DOWNLOAD_COMMAND_H_

#include "DownloadCommand.h"
#include "DownloadEngine.h"
#include "Socket.h"
#include "Request.h"
#include "common.h"
#include "TransferEncoding.h"
#include <string>
#include <map>

using namespace std;

class HttpDownloadCommand:public DownloadCommand {
private:
  map<string, TransferEncoding*> transferEncodings;
protected:
  virtual bool prepareForNextSegment(const Segment& currentSegment);
public:
  HttpDownloadCommand(int cuid, const RequestHandle req, DownloadEngine* e,
		      const SocketHandle& s);
  ~HttpDownloadCommand();

  TransferEncoding* getTransferEncoding(const string& transferEncoding);
};

#endif // _D_HTTP_DOWNLOAD_COMMAND_H_

==> aria2_1.8.0.orig.tar.gz: aria2-1.8.0/src/HttpDownloadCommand.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef _D_HTTP_DOWNLOAD_COMMAND_H_
#define _D_HTTP_DOWNLOAD_COMMAND_H_

#include "DownloadCommand.h"

namespace aria2 {

class HttpResponse;
class HttpConnection;

class HttpDownloadCommand : public DownloadCommand {
private:
  SharedHandle<HttpResponse> _httpResponse;
  SharedHandle<HttpConnection> _httpConnection;
protected:
  virtual bool prepareForNextSegment();
public:
  HttpDownloadCommand(int cuid,
		      const SharedHandle<Request>& req,
		      const SharedHandle<FileEntry>& fileEntry,
		      RequestGroup* requestGroup,
		      const SharedHandle<HttpResponse>& httpResponse,
		      const SharedHandle<HttpConnection>& httpConnection,
		      DownloadEngine* e,
		      const SharedHandle<SocketCore>& s);
  virtual ~HttpDownloadCommand();
};

} // namespace aria2

#endif // _D_HTTP_DOWNLOAD_COMMAND_H_
